"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const generateRedirectFileDefault_1 = __importDefault(require("./generateRedirectFileDefault"));
describe('generateRedirectFileDefault', () => {
    const defaultParams = {
        importGenerateUrl: { namedImports: [{ name: 'generateUrl' }], from: 'route-codegen' },
        routeName: 'Login',
        patternNamedExports: {
            filename: 'patternLogin',
            patternName: 'patternLogin',
            urlPartsInterfaceName: 'UrlPartsLogin',
            patternNameNextJS: 'patternNextJSLogin',
        },
        destinationDir: 'path/to/routes',
    };
    it('should generate correctly if no path params', () => {
        const templateFile = generateRedirectFileDefault_1.default(Object.assign({}, defaultParams));
        expect(templateFile.filename).toBe('RedirectLogin');
        expect(templateFile.extension).toBe('.tsx');
        expect(templateFile.destinationDir).toBe('path/to/routes');
        expect(templateFile.template).toContain(`import React, {useEffect,} from 'react'
  import {generateUrl,} from 'route-codegen'
  import {UrlPartsLogin,patternLogin,} from './patternLogin'
  const RedirectLogin: React.FunctionComponent<UrlPartsLogin & { fallback?: React.ReactNode }> = props => {
    const to = generateUrl(patternLogin, {}, props.urlQuery);
    useEffect(() => {
      if (window && window.location) {
        window.location.href = to;
      }
    }, [to]);
    return <>{props.fallback}</>;
  };
  export default RedirectLogin`);
    });
    it('should generate correctly with path params', () => {
        const templateFile = generateRedirectFileDefault_1.default(Object.assign(Object.assign({}, defaultParams), { patternNamedExports: Object.assign(Object.assign({}, defaultParams.patternNamedExports), { pathParamsInterfaceName: 'PathParamsLogin' }) }));
        expect(templateFile.filename).toBe('RedirectLogin');
        expect(templateFile.extension).toBe('.tsx');
        expect(templateFile.destinationDir).toBe('path/to/routes');
        expect(templateFile.template).toContain(`import React, {useEffect,} from 'react'
  import {generateUrl,} from 'route-codegen'
  import {UrlPartsLogin,patternLogin,} from './patternLogin'
  const RedirectLogin: React.FunctionComponent<UrlPartsLogin & { fallback?: React.ReactNode }> = props => {
    const to = generateUrl(patternLogin, props.path, props.urlQuery);
    useEffect(() => {
      if (window && window.location) {
        window.location.href = to;
      }
    }, [to]);
    return <>{props.fallback}</>;
  };
  export default RedirectLogin`);
    });
});
//# sourceMappingURL=generateRedirectFileDefault.test.js.map