"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const generateRedirectFileReactRouterV5_1 = __importDefault(require("./generateRedirectFileReactRouterV5"));
describe('generateRedirectFileReactRouterV5', () => {
    const defaultParams = {
        importGenerateUrl: { namedImports: [{ name: 'generateUrl' }], from: 'route-codegen' },
        routeName: 'Login',
        patternNamedExports: {
            filename: 'patternLogin',
            patternName: 'patternLogin',
            urlPartsInterfaceName: 'UrlPartsLogin',
            patternNameNextJS: 'patternNextJSLogin',
        },
        destinationDir: 'path/to/routes',
    };
    it('should generate correctly if no path params', () => {
        const templateFile = generateRedirectFileReactRouterV5_1.default(Object.assign({}, defaultParams));
        expect(templateFile.filename).toBe('RedirectLogin');
        expect(templateFile.extension).toBe('.tsx');
        expect(templateFile.destinationDir).toBe('path/to/routes');
        expect(templateFile.template).toContain(`import React from 'react'
  import {generateUrl,} from 'route-codegen'
  import {Redirect,} from 'react-router'
  import {UrlPartsLogin,patternLogin,} from './patternLogin'
  const RedirectLogin: React.FunctionComponent<UrlPartsLogin & { fallback?: React.ReactNode }> = props => {
    const to = generateUrl(patternLogin, {}, props.urlQuery);
    return (
      <>
        <Redirect to={to} />
        {props.fallback}
      </>
    );
  };
  export default RedirectLogin`);
    });
    it('should generate correctly with path params', () => {
        const templateFile = generateRedirectFileReactRouterV5_1.default(Object.assign(Object.assign({}, defaultParams), { patternNamedExports: Object.assign(Object.assign({}, defaultParams.patternNamedExports), { pathParamsInterfaceName: 'PathParamsLogin' }) }));
        expect(templateFile.filename).toBe('RedirectLogin');
        expect(templateFile.extension).toBe('.tsx');
        expect(templateFile.destinationDir).toBe('path/to/routes');
        expect(templateFile.template).toContain(`import React from 'react'
  import {generateUrl,} from 'route-codegen'
  import {Redirect,} from 'react-router'
  import {UrlPartsLogin,patternLogin,} from './patternLogin'
  const RedirectLogin: React.FunctionComponent<UrlPartsLogin & { fallback?: React.ReactNode }> = props => {
    const to = generateUrl(patternLogin, props.path, props.urlQuery);
    return (
      <>
        <Redirect to={to} />
        {props.fallback}
      </>
    );
  };
  export default RedirectLogin`);
    });
});
//# sourceMappingURL=generateRedirectFileReactRouterV5.test.js.map